@@ -490,6 +490,9 @@ class GPT2LMModel(nn.Module):
             
             if key.startswith("module.transformer."):
                 new_key = key[len("module.transformer."):]
+            
+            if key.startswith("transformer."):
+                new_key = key[len("transformer."):]
 
             if new_key:
                 old_keys.append(key)
